@@ -1,9 +1,8 @@
-from django.shortcuts import render
 from rest_framework import filters
 from django_filters.rest_framework import DjangoFilterBackend
 
-from utils.page import YzPageSetPagination
-from utils.yzModelViewSet import YzModelViewSet
+from ..utils.page import YzPageSetPagination
+from ..utils.yzModelViewSet import YzModelViewSet
 from . import serializer
 from . import models
 from . import  filter
